@echo off

REM -- ------------------------------------------------------
REM -- 
REM -- FILE          : silbuf.bat
REM --               :
REM -- AUTHOR        : Jeff Holton / jeffholton at mac dot com
REM --               :
REM -- DATE          : Not sure. Sometime in early 2011.
REM --               :
REM -- PURPOSE       : Add one second of silence at the 
REM --               : beginning of every WAV file in a folder
REM --               :
REM -- DEPENDENCIES  : You will need to install sox. You can 
REM --               : get sox at http://bit.ly/sox-sound
REM --               :
REM -- USE           : Drop the zip file into a folder where
REM --               : there are a bunch of WAV files.
REM --               : (Course, if you're reading this, you
REM --               : must have already done that. Or
REM --               :
REM --               : something kinda like it.) Open up
REM --               : silbuftask and make sure it points
REM --               : to sox properly. This depends on
REM --               : where you installed sox. Execute
REM --               : silbuf. When it's done, check your
REM --               : output in the converted subfolder.
REM --               : Your originals will not have been
REM --               : changed.
REM --               : 
REM --               : You may have to use a different
REM --               : 1-sec-silence.wav file to match
REM --               : the requirements imposed by your
REM --               : WAV files.
REM --               :
REM -- METHOD        : All this script does is create the
REM --               : subfolder where the converted files
REM --               : will be stored, moves the "silence"
REM --               : file into that folder, and then calls
REM --               : the other script, silbuftask, to 
REM --               : perform the actual conversion task on
REM --               : each WAV file.
REM --               :
REM -- PRECONDITION  : You have zero or more WAV (*.wav)
REM --               : files in a folder.
REM --               :
REM -- POSTCONDITION : All of the WAV files have had a
REM --               : second of silence prepended to the
REM --               : beginning, and the new files have
REM --               : been placed in the directort created
REM --               : below.
REM --               :
REM -- NOTE          : I created the included one-second
REM --               : silence file with Audacity. Very easy
REM --               : to use. And highly recommended if you
REM --               : need to do it yourself. You can get
REM --               : it at http://bit.ly/aud-sound
REM --               :
REM -- LINKS         : http://bit.ly/sox-sound
REM --               : http://bit.ly/aud-sound
REM -- 
REM -- -------------------------------------------------------

mkdir converted
@echo Created temp directory.
move 1-sec-silence.wav converted/
FOR %%a in (*.wav) DO call silbuftask %%a 
